import 'package:flutter/material.dart';
import 'package:login_screen/bottomnavigationbar/page1.dart';
import 'package:login_screen/bottomnavigationbar/page2.dart';
import 'package:login_screen/bottomnavigationbar/page3.dart';
import 'package:login_screen/bottomnavigationbar/page4.dart';
import 'package:login_screen/bottomnavigationbar/page5.dart';

class NavBar7 extends StatefulWidget {
  const NavBar7({Key? key}) : super(key: key);
  @override
  State<NavBar7> createState() => _NavBar7State();
}
class _NavBar7State extends State<NavBar7> with TickerProviderStateMixin {
  int _selectedIndex = 0;
  List pages = [
    const Page1(),
    const Page2(),
    const Page3(),
    const Page4(),
    const Page5(),
  ];
  List labels=[
    'Home',
    'Message',
    'Cart',
    'Profile'
  ];
  List icon=[
    Icons.home,
    Icons.message,
    Icons.shopping_cart,
    Icons.person
  ];

  late AnimationController controller;
  late Animation<double> animation;
  late double position;

  @override
  void initState(){
    controller=AnimationController(vsync: this,duration: const Duration(milliseconds: 400));
    animation=CurvedAnimation(parent: controller, curve: Curves.easeOutBack);
    position=0;
    super.initState();
  }

  // @override
  // void didChangeDependencies(){
  //   animation= Tween(begin: getEndPosition(0),end: getEndPosition(0)).animate(
  //     CurvedAnimation(parent: controller, curve: Curves.easeOutBack));
  //   position=getEndPosition(0);
  //   super.didChangeDependencies();
  // }

  double getEndPosition(int index){
    return index*MediaQuery.of(context).size.width/4;
  }

  void animateBar(int index){
    animation=Tween(begin: position, end: getEndPosition(index)).animate(
      CurvedAnimation(parent: controller, curve: Curves.easeOutBack));
    controller.forward().then((value){
      position=getEndPosition(index);
      controller.dispose();
      controller=AnimationController(vsync: this,duration: Duration(milliseconds: 400) );
    });
  }



  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    const myColor=Colors.deepOrange;
    return Scaffold(
      extendBody: true,
      body: pages[_selectedIndex],
      bottomNavigationBar: Stack(
        alignment: Alignment.bottomCenter, // Align children to the bottom of the Stack
        children: [
          AnimatedBuilder(
            animation: controller,
            builder: (context, child){
              return ClipPath(
                clipper: MyClipper(x: animation.value),
                child: Container(
                  height: screenSize.height * 0.067,
                  width: screenSize.width,
                  color: myColor,
                ),
              );
            },

          ),
          Row(
            children: List.generate(
              labels.length,
                  (index) {
                return GestureDetector(
                  onTap: () {
                    setState(() {
                      _selectedIndex = index;
                      animateBar(index);
                    });
                  },
                  child: AnimatedContainer(
                    color: Colors.transparent,
                    height: 82,
                    alignment: Alignment.bottomCenter,
                    duration: const Duration(milliseconds: 200),
                    width: screenSize.width * 0.25,
                    padding: EdgeInsets.only(bottom: _selectedIndex == index ? 30 :5),
                    child: Column(
                      // mainAxisSize: MainAxisSize.min,
                       mainAxisAlignment: MainAxisAlignment.end, // Vertically center-align the children
                      children: [
                        Icon(
                          icon[index],
                          color: _selectedIndex == index ? myColor : Colors.white,
                          size: _selectedIndex == index ?35:25,
                        ),
                        Visibility(
                          visible: _selectedIndex!=index,
                          child: Text(
                            '${labels[index]}',
                            style: const TextStyle(
                              color: Colors.white ,
                            ),
                          ),
                        )
                      ],
                    ),
                  ),
                );
              },
            ),
          ),
        ],
      ),
    );





  }


}

class MyClipper extends CustomClipper<Path>{
  double x=0;

   MyClipper({required this.x }) ;

  @override
  Path getClip(Size size) {
    Path path =Path();
    path.moveTo(0+x, 0);
    path.quadraticBezierTo(size.width*.04+x, 0, size.width*.06+x, size.height*.25);
    path.quadraticBezierTo(size.width*.08+x, size.height*.5, size.width*.12+x, size.height*.5);
    path.quadraticBezierTo(size.width*.16+x, size.height*.5, size.width*.18+x, size.height*.25);
    path.quadraticBezierTo(size.width*.20+x, 0, size.width*.24+x, 0);
    path.lineTo(size.width, 0);
    path.lineTo(size.width, size.height);
    path.lineTo(0, size.height);
    path.lineTo(0, 0);
    return path;
  }

  @override
  bool shouldReclip(covariant CustomClipper<Path> oldClipper) {

    return true;
  }

}
